
enum
{
	ID_SearchTextCtrl,
	ID_SearchTree,
	ID_NewButton,
	ID_EditButton,
	ID_RemoveButton,
	ID_PlainTextCtrl,
	ID_HtmlTextCtrl,
	ID_MenuFileExit,
	ID_MenuFileConfig,
	ID_MenuFileNew,
	ID_MenuFileEdit,
	ID_MenuFileSave,
	ID_MenuFileRemove
};
